Poweron Xbox Console
====================

Usage:
::

    usage: xbox-poweron [-h] [--address ADDRESS] liveid

    Power on xbox one console

    positional arguments:
      liveid                Console Live ID

    optional arguments:
      -h, --help            show this help message and exit
      --address ADDRESS, -a ADDRESS
                            IP address of console

Example:
::

    xbox-poweron FD001212413531523
